==> hoteldruid-mod-nl_2.2.1-1.zip: nl/storia_soldi.php <==
<?php

switch ($messaggio) {

case "Vedi le modifiche":  			$messaggio = "Bekijk de veranderingen"; break;
case "dal":  					$messaggio = "van"; break;
case "al":  					$messaggio = "naar"; break;
case "Senza colori":  				$messaggio = "Zonder kleuren"; break;
case "Con colori":  				$messaggio = "Met kleuren"; break;
case "fino al":  				$messaggio = "aan"; break;
case "Storia delle entate e uscite delle prenotazioni inserite nel":	$messaggio = "Betalings historie van ingevoegde reserveringen"; break;
case "Dati della prenotazione":  		$messaggio = "Reserverings datum"; break;
case "Pagato prima":  				$messaggio = "Betaald voor"; break;
case "Pagato dopo":  				$messaggio = "Betaald na"; break;
case "Saldo":  					$messaggio = "Verschil"; break;
case "Data_della modifica":  			$messaggio = "Wijzig datum"; break;
case "Cognome_cliente":  			$messaggio = "Gast_achternaam"; break;
case "Data_iniziale":  				$messaggio = "Begin_datum"; break;
case "Data_finale":  				$messaggio = "Eind_datum"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Trasferito in cassa":  			$messaggio = "Verplaatst in contant box"; break;
case "RESTO":  					$messaggio = "RESTANT"; break;
case "pagine":  				$messaggio = "paginas"; break;
case "Cliente":  				$messaggio = "Gast"; break;
case "Utente":  				$messaggio = "Gebruiker"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEE"; break;
case "Azzera entrate e uscite prenotazioni":  	$messaggio = "Wis alle reserverings betalingen"; break;
case "Metodo":  				$messaggio = "Wijze"; break;
case "Vedi solo le entrate-uscite":  		$messaggio = "Bekijk alleen betalingen"; break;
case "con metodo":  				$messaggio = "op wijze"; break;
case "N°":  					$messaggio = "N."; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>azzerare</b></div> tutte le entrate e le uscite delle prenotazioni e i soldi trasferiti in cassa del":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete</b></div> all reservations payments and money transferred in cash box of"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.zip: nl/storia_soldi.php <==
<?php

switch ($messaggio) {

case "Vedi le modifiche":  			$messaggio = "Bekijk de veranderingen"; break;
case "dal":  					$messaggio = "van"; break;
case "al":  					$messaggio = "naar"; break;
case "Senza colori":  				$messaggio = "Zonder kleuren"; break;
case "Con colori":  				$messaggio = "Met kleuren"; break;
case "fino al":  				$messaggio = "aan"; break;
case "Storia delle entate e uscite delle prenotazioni inserite nel":	$messaggio = "Betalings historie van ingevoegde reserveringen"; break;
case "Dati della prenotazione":  		$messaggio = "Reserverings datum"; break;
case "Pagato prima":  				$messaggio = "Betaald voor"; break;
case "Pagato dopo":  				$messaggio = "Betaald na"; break;
case "Saldo":  					$messaggio = "Verschil"; break;
case "Data_della modifica":  			$messaggio = "Wijzig datum"; break;
case "Cognome_cliente":  			$messaggio = "Gast_achternaam"; break;
case "Data_iniziale":  				$messaggio = "Begin_datum"; break;
case "Data_finale":  				$messaggio = "Eind_datum"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Trasferito in cassa":  			$messaggio = "Verplaatst in contant box"; break;
case "RESTO":  					$messaggio = "RESTANT"; break;
case "pagine":  				$messaggio = "paginas"; break;
case "Cliente":  				$messaggio = "Gast"; break;
case "Utente":  				$messaggio = "Gebruiker"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEE"; break;
case "Azzera entrate e uscite prenotazioni":  	$messaggio = "Wis alle reserverings betalingen"; break;
case "Metodo":  				$messaggio = "Wijze"; break;
case "Vedi solo le entrate-uscite":  		$messaggio = "Bekijk alleen betalingen"; break;
case "con metodo":  				$messaggio = "op wijze"; break;
case "N°":  					$messaggio = "N."; break;
case "Id":  					$messaggio = "Id"; break;
case "Storico Entrate":  			$messaggio = "Payments History"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>azzerare</b></div> tutte le entrate e le uscite delle prenotazioni e i soldi trasferiti in cassa del":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete</b></div> all reservations payments and money transferred in cash box of"; break;
case "Note":  					$messaggio = "Notes"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
